#[non_exhaustive]pub enum LoadDefect {
UnknownEffect,
InvalidText,
OutOfBoundsValue,
OutOfBoundsPtr,
}Expand description
TODO: https://users.rust-lang.org/t/validation-monad/117894/6
this is a way cleaner and nicer approach. Provice a lot of data about the Error, like position in file, expected value, received value, … maybe even allow to cancel the parsing via ControlFlow<(), ()>
load was partially successful. These are the defects that are in the now loaded project
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnknownEffect
deletes the effect
InvalidText
replaced with empty text
OutOfBoundsValue
tries to replace with a sane default value
OutOfBoundsPtr
skips loading of the pointed to value