parse_song

Function parse_song 

pub fn parse_song<R: Read + Seek>(reader: &mut R) -> Result<Song, LoadErr>
Default parsing of a song. Should be fine for most usecases. If you want more customization use the different parsing functions directly.

R should be buffered in some way and not do a syscall on every read. If you ever find yourself using multiple different reader and/or handlers please open an issue on Github, i will change this to take &dyn.