pub struct SampleFormatConvert(/* private fields */);Expand description
don’t understand what bit 3 is supposed to do
Implementations
Sourceimpl SampleFormatConvert
impl SampleFormatConvert
pub fn is_signed(self) -> bool
Sourcepub fn is_big_endian(self) -> bool
pub fn is_big_endian(self) -> bool
should only be true for very old files (isn’t even supported in C schism)
Sourcepub fn delta_samples(self) -> bool
pub fn delta_samples(self) -> bool
alternative is PCM samples
Sourcepub fn byte_delta(self) -> bool
pub fn byte_delta(self) -> bool
not supported
Sourcepub fn tx_wave_12bit(self) -> bool
pub fn tx_wave_12bit(self) -> bool
don’t support in first step
Sourcepub fn should_show_stereo_prompt(self) -> bool
pub fn should_show_stereo_prompt(self) -> bool
don’t know if this also means that the sample is stereo