Module manager

Module manager 

Structs

AudioManager
You will need to write your own spin loops. For that you can and maybe should use AudioManager::buffer_time.
OutputConfig
SongEdit
the changes made to the song will be made available to the playing live audio as soon as this struct is dropped.

Enums

PlaybackSettings
SendResult
ToWorkerMsg