SongEdit

Struct SongEdit 

pub struct SongEdit<'a> { /* private fields */ }
the changes made to the song will be made available to the playing live audio as soon as this struct is dropped.

With this you can load the full song without ever playing a half initialised state when doing mulitple operations this object should be kept as it is

Implementations

Source

impl SongEdit<'_>

pub fn apply_operation( &mut self, op: SongOperation, ) -> Result<(), SongOperation>

pub fn song(&self) -> &Song

pub fn finish(self)

Finish the changes and publish them to the live playing song. Equivalent to std::mem::drop(SongEdit)