pub struct InPatternPosition {
pub row: u16,
pub channel: u8,
}Expand description
both row and channel are zero based. If this ever changes a lot of the implementations of Pattern need to be changed, because the searching starts working differently
Fields
row: u16channel: u8Trait Implementations
Sourceimpl Clone for InPatternPosition
impl Clone for InPatternPosition
Sourcefn clone(&self) -> InPatternPosition
fn clone(&self) -> InPatternPosition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InPatternPosition
impl Debug for InPatternPosition
Sourceimpl Index<InPatternPosition> for Pattern
impl Index<InPatternPosition> for Pattern
Sourceimpl IndexMut<InPatternPosition> for Pattern
impl IndexMut<InPatternPosition> for Pattern
Sourceimpl Ord for InPatternPosition
impl Ord for InPatternPosition
Sourcefn cmp(&self, other: &InPatternPosition) -> Ordering
fn cmp(&self, other: &InPatternPosition) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for InPatternPosition
impl PartialEq for InPatternPosition
Sourceimpl PartialOrd for InPatternPosition
impl PartialOrd for InPatternPosition
impl Copy for InPatternPosition
impl Eq for InPatternPosition
impl StructuralPartialEq for InPatternPosition