Pattern

Struct Pattern 

pub struct Pattern { /* private fields */ }

Implementations

Source

impl Pattern

pub const MAX_ROWS: u16 = 200u16

pub const DEFAULT_ROWS: u16 = 64u16

pub const fn new(len: u16) -> Self

panics if len larger than ‘Self::MAX_LEN’

pub fn set_length(&mut self, new_len: u16)

panics it the new len is larger than ‘Self::MAX_LEN’ deletes the data on higher rows

pub fn set_event(&mut self, position: InPatternPosition, event: NoteEvent)

overwrites the event if the row already has an event for that channel panics if the row position is larger than current amount of rows

pub fn get_event(&self, index: InPatternPosition) -> Option<&NoteEvent>

pub fn get_event_mut( &mut self, index: InPatternPosition, ) -> Option<&mut NoteEvent>

pub fn remove_event(&mut self, position: InPatternPosition)

if there is no event, does nothing

pub const fn row_count(&self) -> u16

pub fn apply_operation(&mut self, op: PatternOperation)

Panics if the Operation is invalid

pub const fn operation_is_valid(&self, op: &PatternOperation) -> bool

pub fn is_empty(&self) -> bool