pub struct ImpulseHeader {Show 20 fields
pub song_name: String,
pub philight: u16,
pub created_with: u16,
pub compatible_with: u16,
pub flags: u16,
pub special: u16,
pub global_volume: u8,
pub mix_volume: u8,
pub initial_speed: u8,
pub initial_tempo: u8,
pub pan_separation: u8,
pub pitch_wheel_depth: u8,
pub message_length: u16,
pub message_offset: u32,
pub channel_pan: [Pan; 64],
pub channel_volume: [u8; 64],
pub orders: Box<[PatternOrder]>,
pub instr_offsets: Box<[Option<InFilePtr>]>,
pub sample_offsets: Box<[Option<InFilePtr>]>,
pub pattern_offsets: Box<[Option<InFilePtr>]>,
}Fields
song_name: Stringphilight: u16created_with: u16compatible_with: u16flags: u16special: u16global_volume: u8mix_volume: u8initial_speed: u8initial_tempo: u8pan_separation: u8pitch_wheel_depth: u8message_length: u16message_offset: u32channel_pan: [Pan; 64]channel_volume: [u8; 64]orders: Box<[PatternOrder]>instr_offsets: Box<[Option<InFilePtr>]>all Offsets are verified to be point outside the header.
Invalid offsets are replaced with None, so patterns or orders don’t break, because the indexes change
sample_offsets: Box<[Option<InFilePtr>]>pattern_offsets: Box<[Option<InFilePtr>]>here None could come from the file, which means an empty pattern
Implementations
Sourceimpl ImpulseHeader
impl ImpulseHeader
Sourcepub fn parse<R: Read, H: FnMut(LoadDefect)>(
reader: &mut R,
defect_handler: &mut H,
) -> Result<Self, LoadErr>
pub fn parse<R: Read, H: FnMut(LoadDefect)>( reader: &mut R, defect_handler: &mut H, ) -> Result<Self, LoadErr>
Reader position needs to be at the beginning of the Header.
Header is stored at the beginning of the File. length isn’t constant, but at least 192 bytes when unable to load specific parts the function tries its best and communicates the failures in the BitFlags return value. For some problems it wouldn’t make sense to return an incomplete Header as so much would be missing. In those cases an Err is returned