Structs
- Audio
Manager - You will need to write your own spin loops. For that you can and maybe should use AudioManager::buffer_time.
- Output
Config - Song
Edit - the changes made to the song will be made available to the playing live audio as soon as this struct is dropped.