pub struct SongEdit<'a> { /* private fields */ }Expand description
the changes made to the song will be made available to the playing live audio as soon as this struct is dropped.
With this you can load the full song without ever playing a half initialised state when doing mulitple operations this object should be kept as it is
Implementations
Sourceimpl SongEdit<'_>
impl SongEdit<'_>
pub fn apply_operation( &mut self, op: SongOperation, ) -> Result<(), SongOperation>
pub fn song(&self) -> &Song