Module pattern

Module pattern 

Structs

InPatternPosition
both row and channel are zero based. If this ever changes a lot of the implementations of Pattern need to be changed, because the searching starts working differently
Pattern

Enums

PatternOperation